@@ -4,7 +4,7 @@
 ## Copyright (C) 2015 Pavol Bauer
 ## Copyright (C) 2017 -- 2019 Robin Eriksson
 ## Copyright (C) 2015 -- 2019 Stefan Engblom
-## Copyright (C) 2015 -- 2021 Stefan Widgren
+## Copyright (C) 2015 -- 2022 Stefan Widgren
 ##
 ## SimInf is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ do_is_trajectory_empty <- function(model, slots) {
     if (!isTRUE(empty)) {
         ## Need to also check the sparse slot.
         empty <- any(vapply(slots, function(name) {
-            any(is.na(slot(model, paste0(name, "_sparse"))))
+            anyNA(slot(model, paste0(name, "_sparse")))
         }, logical(1)))
     }
 
