@@ -4,7 +4,7 @@
 ## Copyright (C) 2015 Pavol Bauer
 ## Copyright (C) 2017 -- 2019 Robin Eriksson
 ## Copyright (C) 2015 -- 2019 Stefan Engblom
-## Copyright (C) 2015 -- 2020 Stefan Widgren
+## Copyright (C) 2015 -- 2022 Stefan Widgren
 ##
 ## SimInf is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -343,8 +343,18 @@ C_code <- c(
     " */",
     "static SEXP SIMINF_MODEL_RUN(SEXP model, SEXP solver)",
     "{",
+    "    static SEXP(*SimInf_run)(SEXP, SEXP, TRFun*, PTSFun) = NULL;",
     "    TRFun tr_fun[] = {&trFun1, &trFun2, &trFun3, &trFun4};",
-    "    DL_FUNC SimInf_run = R_GetCCallable(\"SimInf\", \"SimInf_run\");",
+    "",
+    "    if (!SimInf_run) {",
+    "        SimInf_run = (SEXP(*)(SEXP, SEXP, TRFun*, PTSFun))",
+    "            R_GetCCallable(\"SimInf\", \"SimInf_run\");",
+    "",
+    "        if (!SimInf_run) {",
+    "            Rf_error(\"Cannot find function 'SimInf_run'.\");",
+    "        }",
+    "    }",
+    "",
     "    return SimInf_run(model, solver, tr_fun, &ptsFun);",
     "}",
     "",
@@ -523,8 +533,18 @@ C_code <- c(
     " */",
     "static SEXP SIMINF_MODEL_RUN(SEXP model, SEXP solver)",
     "{",
+    "    static SEXP(*SimInf_run)(SEXP, SEXP, TRFun*, PTSFun) = NULL;",
     "    TRFun tr_fun[] = {&trFun1, &trFun2, &trFun3, &trFun4};",
-    "    DL_FUNC SimInf_run = R_GetCCallable(\"SimInf\", \"SimInf_run\");",
+    "",
+    "    if (!SimInf_run) {",
+    "        SimInf_run = (SEXP(*)(SEXP, SEXP, TRFun*, PTSFun))",
+    "            R_GetCCallable(\"SimInf\", \"SimInf_run\");",
+    "",
+    "        if (!SimInf_run) {",
+    "            Rf_error(\"Cannot find function 'SimInf_run'.\");",
+    "        }",
+    "    }",
+    "",
     "    return SimInf_run(model, solver, tr_fun, &ptsFun);",
     "}",
     "",
@@ -677,8 +697,18 @@ C_code <- c(
     " */",
     "static SEXP SIMINF_MODEL_RUN(SEXP model, SEXP solver)",
     "{",
+    "    static SEXP(*SimInf_run)(SEXP, SEXP, TRFun*, PTSFun) = NULL;",
     "    TRFun tr_fun[] = {&trFun1, &trFun2};",
-    "    DL_FUNC SimInf_run = R_GetCCallable(\"SimInf\", \"SimInf_run\");",
+    "",
+    "    if (!SimInf_run) {",
+    "        SimInf_run = (SEXP(*)(SEXP, SEXP, TRFun*, PTSFun))",
+    "            R_GetCCallable(\"SimInf\", \"SimInf_run\");",
+    "",
+    "        if (!SimInf_run) {",
+    "            Rf_error(\"Cannot find function 'SimInf_run'.\");",
+    "        }",
+    "    }",
+    "",
     "    return SimInf_run(model, solver, tr_fun, &ptsFun);",
     "}",
     "",
